@@ -35,4 +35,13 @@ ciTarLag <- function(y, x, model = c("tar","mtar"), maxlag, thresh,
   result <- list(path=path, out=out)
   class(result) <- "ciTarLag"
   return(result)
+}
+
+plot.ciTarLag <- function(x, ...)
+{
+  xlabel <- paste("Lag value (model = ", x$out[1,2], 
+      ", threshold = ", x$out[3, 2], ")")
+  par(mfrow=c(2,1))
+  plot(aic~lag, data=x$path, type="l", col="green", xlab=xlabel, ylab="AIC")
+  plot(bic~lag, data=x$path, type="l", col="red", xlab=xlabel, ylab="BIC")
 }
\ No newline at end of file
