@@ -1,32 +1,28 @@
-ciTarThd <- function(y, x, model = c("tar", "mtar"), lag, th.range = 0.15, 
-  digits = 3, ...)
+ciTarThd <- function(y, x, model = c("tar", "mtar"), lag, 
+  th.range = 0.15, digits = 3, ...)
 {
   if(!is.ts(y) | !is.ts(x) ) {stop("Please provide time series data.\n")}
   if (!identical(tsp(y),tsp(x))) stop("Properties of y and x are different.\n")
   model <- match.arg(model)
   
   Q <- ciTarFit(y = y, x = x, model = model, lag = lag, thresh = 0)
-  if(model=="tar")  { thresh.test <- sort(as.vector(Q$lz )) } 
-  if(model=="mtar") { thresh.test <- sort(as.vector(Q$ldz)) }
+  if(model == "tar")  { thresh.test <- sort(as.vector(Q$lz )) } 
+  if(model == "mtar") { thresh.test <- sort(as.vector(Q$ldz)) }
   obs.tot <- NROW(y); obs.CI  <- nrow(Q$data.CI)
   a <-        ceiling(obs.CI * th.range)
   b <- obs.CI - floor(obs.CI * th.range)
   
-  path.num <- path.thr <- path.sse <- path.aic <- path.bic <- NULL
-  sse.lowest <- thresh.final <- 10^20
+  path <- data.frame(matrix(0, ncol = 5, nrow = b - a + 1))
+  colnames(path) <- paste("path", c("num", "thr", "sse", "aic", "bic"), sep = '.')
+  path$path.num <- 1:(b - a + 1)
+  path$path.thr <- thresh.test[a:b]   
   for(i in a:b) {
     H <- ciTarFit(y=y, x=x, model=model, lag=lag, thresh=thresh.test[i])
-    path.num[i-a+1] <- i-a+1
-    path.thr[i-a+1] <- thresh.test[i]
-    path.sse[i-a+1] <- as.numeric(H$sse)
-    path.aic[i-a+1] <- as.numeric(H$aic)
-    path.bic[i-a+1] <- as.numeric(H$bic)
-    if ( sse.lowest >  H$sse ) {
-         sse.lowest <- H$sse
-         thresh.final <- thresh.test[i]
-    }
-  }
-  path <- data.frame(path.num, path.thr, path.sse, path.aic, path.bic)
+    path[(i-a+1), 3:5] <- c(H$sse, H$aic, H$bic) 
+  }  
+  sse.lowest <- min(path$path.sse)
+  thresh.final <- path[which(sse.lowest == path$path.sse)[1], 2]
+
   Item <- c("lag", "thresh final", "thresh range", "sse.lowest", 
      "Total obs", "CI obs", "Lower obs", "Upper obs")
   Value <- round(c(lag, thresh.final, th.range, sse.lowest,
@@ -39,4 +35,15 @@ ciTarThd <- function(y, x, model = c("tar", "mtar"), lag, th.range = 0.15,
       basic=basic, path=path)
   class(result) <- "ciTarThd"
   return(result)
-} 
\ No newline at end of file
+} 
+
+plot.ciTarThd <- function(x, ...)
+{
+  par(mfrow=c(2,2))
+  plot(path.sse~path.thr, data=x$path, type="l", col="blue", 
+     ylab="SSE", xlab=paste("threshold value for", x$model))
+  plot(path.aic~path.thr, data=x$path, type="l", col="green",
+     xlab=paste("threshold value for", x$model))
+  plot(path.bic~path.thr, data=x$path, type="l", col="red",
+     xlab=paste("threshold value for", x$model))
+}
\ No newline at end of file
